@@ -42,15 +42,13 @@ def test_simple_put():
 def test_simple_get():
 
     tiddler = tiddlers[0]
-    tiddler.bag = 'bagone'
+    tiddler.bag = u'bagone'
     store.put(tiddler)
 
     bag = Bag(name='bagone')
     bag = store.get(bag)
 
-    assert bag.list_tiddlers()[0].title == tiddler.title
-    assert bag.list_tiddlers()[0].text == ''
-    assert bag.list_tiddlers()[0].tags == []
+    the_tiddler = store.list_bag_tiddlers(bag).next()
     assert bag.policy.read == bagone.policy.read
     assert bag.policy.write == bagone.policy.write
     assert bag.policy.create == bagone.policy.create
@@ -59,9 +57,8 @@ def test_simple_get():
     assert bag.policy.owner == bagone.policy.owner
     assert bag.desc == 'I enjoy being stored'
     
-    the_tiddler = bag.list_tiddlers()[0]
     the_tiddler = store.get(the_tiddler)
-    assert the_tiddler.title == tiddler.title, 'stored tiddler title and retrieved tiddler.title the same'
+    assert the_tiddler.title == tiddler.title
     assert sorted(the_tiddler.tags) == sorted(tiddler.tags)
 
 def test_failed_get():
